@@ -116,6 +116,10 @@ SOFTWARE.
 #endif
 #endif
 
+#ifdef HAVE_SYS_UCRED_H
+#include <sys/ucred.h>
+#endif
+
 #ifdef HAVE_SYS_UN_H
 #include <sys/un.h>
 #endif
@@ -187,6 +191,8 @@ SOFTWARE.
 #include "osdep.h"
 
 #include "xace.h"
+#include "rpcauth.h"
+#include "xdmcp.h"
 
 Bool defeatAccessControl = FALSE;
 
@@ -436,20 +442,11 @@ DefineSelf(int fd)
 #if !defined(TCPCONN) && !defined(UNIXCONN)
     return;
 #else
-    register int n;
     int len;
     caddr_t addr;
     int family;
     register HOST *host;
-
-#ifndef WIN32
     struct utsname name;
-#else
-    struct {
-        char nodename[512];
-    } name;
-#endif
-
     register struct hostent *hp;
 
     union {
@@ -461,7 +458,9 @@ DefineSelf(int fd)
     } saddr;
 
     struct sockaddr_in *inetaddr;
+#if defined(IPv6) && defined(AF_INET6)
     struct sockaddr_in6 *inet6addr;
+#endif
     struct sockaddr_in broad_addr;
 
 #ifdef XTHREADS_NEEDS_BYNAMEPARAMS
@@ -473,11 +472,7 @@ DefineSelf(int fd)
      * uname() lets me access to the whole string (it smashes release, you
      * see), whereas gethostname() kindly truncates it for me.
      */
-#ifndef WIN32
     uname(&name);
-#else
-    gethostname(name.nodename, sizeof(name.nodename));
-#endif
 
     hp = _XGethostbyname(name.nodename, hparams);
     if (hp != NULL) {
@@ -1166,7 +1161,7 @@ ComputeLocalClient(ClientPtr client)
 int
 GetLocalClientCreds(ClientPtr client, LocalClientCredRec ** lccp)
 {
-#if defined(HAVE_GETPEEREID) || defined(HAVE_GETPEERUCRED) || defined(SO_PEERCRED)
+#if defined(HAVE_GETPEEREID) || defined(HAVE_GETPEERUCRED) || defined(SO_PEERCRED) || defined(LOCAL_PEERCRED)
     int fd;
     XtransConnInfo ci;
     LocalClientCredRec *lcc;
@@ -1175,7 +1170,14 @@ GetLocalClientCreds(ClientPtr client, LocalClientCredRec ** lccp)
     ucred_t *peercred = NULL;
     const gid_t *gids;
 #elif defined(SO_PEERCRED)
+#ifndef __OpenBSD__
     struct ucred peercred;
+#else
+    struct sockpeercred peercred;
+#endif
+    socklen_t so_len = sizeof(peercred);
+#elif defined(LOCAL_PEERCRED) && defined(HAVE_XUCRED_CR_PID)
+    struct xucred peercred;
     socklen_t so_len = sizeof(peercred);
 #elif defined(HAVE_GETPEEREID)
     uid_t uid;
@@ -1253,6 +1255,17 @@ GetLocalClientCreds(ClientPtr client, LocalClientCredRec ** lccp)
     lcc->pid = peercred.pid;
     lcc->fieldsSet = LCC_UID_SET | LCC_GID_SET | LCC_PID_SET;
     return 0;
+#elif defined(LOCAL_PEERCRED) && defined(HAVE_XUCRED_CR_PID)
+    if (getsockopt(fd, SOL_LOCAL, LOCAL_PEERCRED, &peercred, &so_len) != 0 ||
+        peercred.cr_version != XUCRED_VERSION) {
+        FreeLocalClientCreds(lcc);
+        return -1;
+    }
+    lcc->euid = peercred.cr_uid;
+    lcc->egid = peercred.cr_gid;
+    lcc->pid = peercred.cr_pid;
+    lcc->fieldsSet = LCC_UID_SET | LCC_GID_SET | LCC_PID_SET;
+    return 0;
 #elif defined(HAVE_GETPEEREID)
     if (getpeereid(fd, &uid, &gid) == -1) {
         FreeLocalClientCreds(lcc);
@@ -1621,13 +1634,6 @@ ChangeAccessControl(ClientPtr client, int fEnabled)
     return Success;
 }
 
-/* returns FALSE if xhost + in effect, else TRUE */
-int
-GetAccessControl(void)
-{
-    return AccessEnabled;
-}
-
 int
 GetClientFd(ClientPtr client)
 {
@@ -1860,7 +1866,7 @@ siHostnameAddrMatch(int family, void *addr, int len,
         char hostname[SI_HOSTNAME_MAXLEN];
         int f, hostaddrlen;
         void *hostaddr;
-        const char **addrlist;
+        char **addrlist;
 
         if (siAddrLen >= sizeof(hostname))
             return FALSE;
